@@ -1,5 +1,5 @@
 package App::Oozie::Deploy;
-$App::Oozie::Deploy::VERSION = '0.010';
+$App::Oozie::Deploy::VERSION = '0.011';
 use 5.014;
 use strict;
 use warnings;
@@ -468,7 +468,7 @@ sub __collect_internal_conf {
 
     # if YARN, use a different property. the oozie syntax doesn't change (still
     # uses the jobtracker property)
-    $config->{jobTracker}     = $config->{resourceManager};
+    $config->{jobTracker}     = $config->{resourceManager} || $self->resource_manager;
     $config->{nameNode}     //= $self->template_namenode;
 
     $config->{has_sla}        = $self->sla;
@@ -1231,7 +1231,7 @@ App::Oozie::Deploy
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
