@@ -1,5 +1,5 @@
 package App::Oozie::Deploy::Validate::Spec::Coordinator;
-$App::Oozie::Deploy::Validate::Spec::Coordinator::VERSION = '0.010';
+$App::Oozie::Deploy::Validate::Spec::Coordinator::VERSION = '0.011';
 use 5.014;
 use strict;
 use warnings;
@@ -13,6 +13,7 @@ use App::Oozie::Types::Common qw( IsFile );
 with qw(
     App::Oozie::Role::Log
     App::Oozie::Role::Fields::Generic
+    App::Oozie::Role::Validate::XML
 );
 
 sub verify {
@@ -52,6 +53,12 @@ sub verify {
             my($h, $key) = @_;
             return if $key ne 'property';
 
+            $self->validate_xml_property(
+                \$validation_errors,
+                \$total_errors,
+                $h->{property},
+            );
+
             for my $property ( @{ $h->{property} } ) {
               my $property_name = defined($property->{name})? $property->{name} : "";
               #if ($property_name eq 'startDate' || $property_name eq 'endDate') {
@@ -100,7 +107,7 @@ App::Oozie::Deploy::Validate::Spec::Coordinator
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
