@@ -1,5 +1,5 @@
 package App::Oozie::Role::Fields::Objects;
-$App::Oozie::Role::Fields::Objects::VERSION = '0.010';
+$App::Oozie::Role::Fields::Objects::VERSION = '0.011';
 use 5.014;
 use strict;
 use warnings;
@@ -18,6 +18,11 @@ use Net::Hadoop::Oozie;
 use Net::Hadoop::WebHDFS::LWP;
 use Types::Standard qw( InstanceOf );
 
+option resource_manager => (
+    is     => 'rw',
+    format => 's',
+);
+
 option timezone => (
     is       => 'rw',
     isa      => IsTZ,
@@ -93,7 +98,7 @@ App::Oozie::Role::Fields::Objects
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -114,6 +119,8 @@ App::Oozie::Role::Fields::Objects - Overridable objects for internal programs/li
 
 =head2 Overridable from cli
 
+=head3 resource_manager
+
 =head3 timezone
 
 =head3 webhdfs_hostname
