@@ -1,5 +1,5 @@
 package App::Oozie::Update::Coordinator;
-$App::Oozie::Update::Coordinator::VERSION = '0.010';
+$App::Oozie::Update::Coordinator::VERSION = '0.011';
 use 5.014;
 use strict;
 use warnings;
@@ -101,6 +101,12 @@ sub run {
 
         push @{ $command }, '-dryrun' if $self->dryrun;
 
+        $logger->info(
+            sprintf "Updating the coordinator (%s) attempt: %s",
+                        $self->coord,
+                        $try,
+        );
+
         $success = IPC::Cmd::run(
                         buffer  => \my $out,
                         command => $command,
@@ -288,6 +294,9 @@ sub _modify_xml {
 
     my $logger = $self->logger;
 
+    $logger->debug( sprintf 'Coordinator XML is being verified ...' )
+        if $self->verbose;
+
     my $twig = XML::Twig->new->parse( ${ $current_xml_ref } )
                 or die "Could not parse the original configuration";
 
@@ -411,6 +420,9 @@ sub _modify_xml {
         );
     }
 
+    $logger->debug( sprintf 'Coordinator XML verification completed.' )
+        if $self->verbose;
+
     return $twig, $prev_state;
 }
 
@@ -466,7 +478,7 @@ App::Oozie::Update::Coordinator
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
